Stan Math Library: stan/math/rev/mat/functor.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

functor.hpp File Reference
`#include <stan/math/rev/mat/functor/gradient.hpp>`
`#include <stan/math/rev/mat/functor/jacobian.hpp>`
`#include <stan/math/rev/mat/functor/ode_system.hpp>`
`#include <stan/math/rev/mat/functor/integrate_ode_bdf.hpp>`

Go to the source code of this file.

[ Stan Home Page ] © 2011–2016, Stan Development Team.